package edu.uoc.pfc.statusdroid.activity;

import java.security.SecureRandom;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;
import android.content.res.Resources;
import android.database.Cursor;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuInflater;
import android.widget.TabHost;
import edu.uoc.pfc.statusdroid.R;
import edu.uoc.pfc.statusdroid.content.StatusDroidDB;
import edu.uoc.pfc.statusdroid.model.ServerConfigData;
import edu.uoc.pfc.statusdroid.model.User;
import edu.uoc.pfc.statusdroid.service.StatusNetAPIService;
import edu.uoc.pfc.statusdroid.utils.Constants;
import edu.uoc.pfc.statusdroid.utils.StatusDroidUtils;

public class MainActivity extends StatusDroidBaseTabActivity {

	// Tag de log
	private static final String LOG_TAG = "MainActivity";

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		Resources res = getResources();
		TabHost tabHost = getTabHost();
		TabHost.TabSpec spec;
		Intent intent;

		// 1 - Pestanya pública
		intent = new Intent().setClass(this, PublicStatusActivity.class);

		// Especificació
		spec = tabHost
				.newTabSpec("public")
				.setIndicator(res.getString(R.string.public_tab),
						res.getDrawable(R.drawable.ic_public_tab))
				.setContent(intent);
		tabHost.addTab(spec);

		// 2 - Pestanya Personal
		intent = new Intent().setClass(this, HomeStatusActivity.class);
		spec = tabHost
				.newTabSpec("home")
				.setIndicator(res.getString(R.string.home_tab),
						res.getDrawable(R.drawable.ic_home_tab))
				.setContent(intent);
		tabHost.addTab(spec);

		// 3 - Pestanya favorits
		intent = new Intent().setClass(this, FavoritesStatusActivity.class);
		spec = tabHost
				.newTabSpec("favorites")
				.setIndicator(res.getString(R.string.favorites_tab),
						res.getDrawable(R.drawable.ic_favorites_tab))
				.setContent(intent);
		tabHost.addTab(spec);

		// 4 - Pestanya missatges
		intent = new Intent().setClass(this, MessageActivity.class);
		spec = tabHost
				.newTabSpec("message")
				.setIndicator(res.getString(R.string.message_tab),
						res.getDrawable(R.drawable.ic_message_tab))
				.setContent(intent);
		tabHost.addTab(spec);

		// 5 - Pestanya Usuari
		intent = new Intent().setClass(this, UserActivity.class);
		spec = tabHost
				.newTabSpec("message")
				.setIndicator(res.getString(R.string.user_tab),
						res.getDrawable(R.drawable.ic_user_tab))
				.setContent(intent);
		tabHost.addTab(spec);

		tabHost.setCurrentTab(0);

	}

	@Override
	protected void onStart() {
		super.onStart();

		// 1 - Generar seed pels passwords si no existeix
		SharedPreferences statusPref = this.getSharedPreferences(
				Constants.PREFS_NAME, Context.MODE_PRIVATE);
		if (null == statusPref || !statusPref.contains(Constants.PREF_SEED)) {
			SecureRandom rng = new SecureRandom();
			byte[] genSeed = rng.generateSeed(8);
			Long seed = 0L;
			for (int i = 0; i < genSeed.length; i++) {
				seed += (genSeed[i] & 0xff) << (8 * i);
			}
			Editor editor = statusPref.edit();
			editor.putString(Constants.PREF_SEED, seed.toString());
			editor.commit();
		}
	}

	@Override
	protected void onResume() {
		super.onResume();
		if (mBound && null == statusNetAPI.getService().getCurrentServer()) {
			loadConfigData();
		}
	}

	@Override
	protected void onStop() {
		super.onStop();
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
		if (StatusNetAPIService.mBound) {
			getApplicationContext().unbindService(mConnection);
			mBound = false;
		}
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		MenuInflater inflater = getMenuInflater();
		inflater.inflate(R.menu.statusdroid_menu, menu);
		return true;
	}

	/**
	 * Mètode que carrega l'alerta d'avís de configuració.
	 */
	private void showConfigAlert() {
		// prepare the alert box
		AlertDialog.Builder alertbox = new AlertDialog.Builder(this);

		// set the message to display
		alertbox.setMessage(getResources().getString(R.string.warn_config));

		// add a neutral button to the alert box and assign a click listener
		alertbox.setNeutralButton(getResources().getString(R.string.button_ok),
				new DialogInterface.OnClickListener() {

					// click listener on the alert box
					public void onClick(DialogInterface arg0, int arg1) {
						Intent intent = new Intent(getApplicationContext(),
								ConfigActivity.class);
						startActivity(intent);
					}
				});

		// show it
		alertbox.show();
	}

	/**
	 * Mètode que recupera la informació de la connexió per defecte, aquella
	 * marcada com a autoconnectar.
	 * 
	 */
	private void loadConfigData() {
		// 1 - Accedim a la base de dades per recuperar la configuració
		Cursor cursor = null;
		try {
			cursor = getApplicationContext().getContentResolver().query(
					StatusDroidDB.ServerConfig.CONTENT_URI, null, null, null,
					null);
			cursor.moveToFirst();

			if (cursor.getCount() == 0) {
				showConfigAlert();
			} else {

				// 2 - Recuperar la configuració de connexió
				ServerConfigData serverConfig = null;

				while (!cursor.isAfterLast()) {
					if (new Boolean(
							cursor.getString(cursor
									.getColumnIndex(StatusDroidDB.ServerConfig.COLUMN_SERVER_AUTOCONN)))) {
						String seed = getSharedPreferences(
								Constants.PREFS_NAME, Context.MODE_PRIVATE)
								.getString(Constants.PREF_SEED, null);
						if (seed != null) {
							serverConfig = StatusDroidUtils
									.recoverServerConfigData(cursor, seed);
						}
					}
					cursor.moveToNext();
				}
				if (serverConfig != null) {
					statusNetAPI.getService().setCurrentServer(serverConfig);
					statusNetAPI.getService().setConnected(true);
				} else {
					statusNetAPI.getService().setConnected(false);
				}
			}
		} catch (Exception e) {
			Log.e(LOG_TAG,
					getResources().getString(R.string.error_recover_config), e);
			showErrorAlert(getResources().getString(
					R.string.error_recover_config));
		} finally {
			if (cursor != null) {
				cursor.close();
			}
		}
	}

	/**
	 * Mètode que carrega les dades de l'usuari actiu al servidor.
	 * 
	 * @param name
	 *            Nom de l'usuari a carregar
	 */
	private void loadUserData(String name) {
		// 1 - Accedim al servei per recuperar la informació
		try {
			User user = statusNetAPI.getUserInfoByName(name);
			statusNetAPI.getService().setUser(user);
		} catch (Exception e) {
			Log.e(LOG_TAG,
					getResources().getString(R.string.error_recover_config), e);
			showErrorAlert(getResources()
					.getString(R.string.error_recover_user));
		}
	}

	@Override
	public void loadServiceAction() {
		if (!statusNetAPI.getService().isConnected()) {
			loadConfigData();
			if (statusNetAPI.getService().getCurrentServer() != null
					&& statusNetAPI.getService().getCurrentServer().getUser() != null) {
				loadUserData(statusNetAPI.getService().getCurrentServer()
						.getUser());
			}
		}
	}

}