package edu.uoc.pfc.statusdroid.activity;

import android.os.Bundle;
import android.view.View;
import android.widget.EditText;
import android.widget.Toast;
import edu.uoc.pfc.statusdroid.R;
import edu.uoc.pfc.statusdroid.exception.StatusDroidException;

/**
 * Classe que conté la lògica de l'activitat per la pestaña d'enviament de
 * missatges
 * 
 * @author daniel
 * 
 */
public class MessageActivity extends StatusDroidBaseActivity {

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.send_message);
	}

	/**
	 * Mètode que controla les accions que es realitzan al premer le butó
	 * esborrar
	 * 
	 * @param v
	 *            Vista on s'ha generat l'acció
	 */
	public void onDelete(View v) {
		EditText textMessage = (EditText) findViewById(R.id.message_text);
		textMessage.setText("");
	}

	/**
	 * Mètode que controla les accions que es realitzan al premer le butó enviar
	 * 
	 * @param v
	 *            Vista on s'ha generat l'acció
	 */
	public void onSend(View v) {
		if (!statusNetAPI.getService().isConnected()) {
			Toast.makeText(this,
					getResources().getString(R.string.warn_connected),
					Toast.LENGTH_SHORT).show();
			return;
		}
		String textMessage = ((EditText) findViewById(R.id.message_text))
				.getText().toString();
		// El missatge no pot ser buit
		if (null == textMessage || textMessage.length() == 0) {
			showErrorAlert(getResources().getString(
					R.string.error_message_empty));
			return;
		}

		// Enviem el missatge
		try {
			statusNetAPI.sendUpdate(textMessage);
		} catch (StatusDroidException e) {
			showErrorAlert(e.getMessage());
			return;
		}

		// Notifiquem
		Toast.makeText(this, getResources().getString(R.string.info_send_ok),
				Toast.LENGTH_SHORT).show();

		// Esborrem el missatge
		((EditText) findViewById(R.id.message_text)).setText("");

	}

}
