package edu.uoc.pfc.statusdroid.activity;

import android.app.AlertDialog;
import android.app.TabActivity;
import android.content.ComponentName;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.IBinder;
import android.view.MenuItem;
import edu.uoc.pfc.statusdroid.R;
import edu.uoc.pfc.statusdroid.service.StatusNetAPIBinder;
import edu.uoc.pfc.statusdroid.service.StatusNetAPIService;

/**
 * Classe d¡activitat base que conté aquells mètodes comuns que poden ser
 * reutilitzats per més d'una activitat.
 * 
 * @author daniel
 * 
 */
public class StatusDroidBaseTabActivity extends TabActivity {

	StatusNetAPIBinder statusNetAPI;
	boolean mBound;

	/**
	 * Classe de Callback per a la connexió amb el servei d'StatusNet
	 * 
	 * @author daniel
	 * 
	 */
	protected class StatusDroidServiceConnection implements ServiceConnection {

		public void onServiceConnected(ComponentName className, IBinder service) {
			statusNetAPI = (StatusNetAPIBinder) service;
			mBound = true;
			loadServiceAction();
		}

		public void onServiceDisconnected(ComponentName arg0) {
			mBound = false;
		}
	}

	// Classe de Callback per a la connexió amb els serveis
	public ServiceConnection mConnection = new StatusDroidServiceConnection();

	/**
	 * Mètode d'utilitat per mostrar missatges d'error a l'usuari
	 * 
	 * @param message
	 *            Missatge a mostrar
	 */
	public void showErrorAlert(String message) {
		AlertDialog.Builder alertbox = new AlertDialog.Builder(this);
		alertbox.setMessage(message);

		// Acció a realitzar
		alertbox.setNeutralButton(getResources().getString(R.string.button_ok),
				new DialogInterface.OnClickListener() {
					public void onClick(DialogInterface arg0, int arg1) {
						// No s'ha de fer res, tornar a la mateixa pantalla
					}
				});
		alertbox.show();
	}

	@Override
	protected void onStart() {
		super.onStart();
		// Enllaçar amb el servei d'StatusNet
		Intent intent = new Intent(this, StatusNetAPIService.class);
		getApplicationContext().bindService(intent, mConnection,
				Context.BIND_AUTO_CREATE);
	}

	/**
	 * Mètode per afegir-hi tasques addicionals a la connexió amb el servei
	 */
	public void loadServiceAction() {
		// Per defecte no fa res
	}

	@Override
	/**
	 * Mètode que tracta les accions del menú principal de l'aplicació
	 * @item menú que s'ha seleccionat
	 * @return resultat de l'acció
	 */
	public boolean onOptionsItemSelected(MenuItem item) {
		Intent intent;
		switch (item.getItemId()) {
		case R.id.menu_home:
			intent = new Intent(this, MainActivity.class);
			startActivity(intent);
			break;
		case R.id.menu_config:
			intent = new Intent(this, ConfigListActivity.class);
			startActivity(intent);
			break;
		// case R.id.menu_help:
		// break;
		default:
			break;
		}
		// Handle item selection
		// switch (item.getItemId()) {
		// case R.id.new_game:
		// newGame();
		// return true;
		// case R.id.help:
		// showHelp();
		// return true;
		// default:
		// return super.onOptionsItemSelected(item);
		// }
		return true;
	}
}
