package edu.uoc.pfc.statusdroid.activity;

import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.widget.CheckBox;
import android.widget.ImageView;
import android.widget.TextView;
import edu.uoc.pfc.statusdroid.R;
import edu.uoc.pfc.statusdroid.exception.StatusDroidException;
import edu.uoc.pfc.statusdroid.model.User;
import edu.uoc.pfc.statusdroid.utils.StatusDroidUtils;

/**
 * Classe que conté la lògica de l'activitat per la pestaña d'usuari
 * 
 * @author daniel
 * 
 */
public class UserActivity extends StatusDroidBaseActivity {

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.user);
	}

	/**
	 * Mètode que genera les dades de la vista a partir de la informació de
	 * l'usuari
	 * 
	 * @param user
	 *            Usuari per a generar la vista
	 */
	private void fillViewFromUser(User user) {
		((TextView) findViewById(R.id.user_data_id)).setText(String
				.valueOf(user.getId()));
		((TextView) findViewById(R.id.user_data_screen_name)).setText(user
				.getScreen_name());
		((TextView) findViewById(R.id.user_data_name)).setText(user.getName());
		((TextView) findViewById(R.id.user_data_followers)).setText(String
				.valueOf(user.getFollowers_count()));
		((TextView) findViewById(R.id.user_data_friends)).setText(String
				.valueOf(user.getFriends_count()));
		if (user.isFollowing()) {
			((CheckBox) findViewById(R.id.user_data_following))
					.setChecked(true);
		} else {
			((CheckBox) findViewById(R.id.user_data_following))
					.setChecked(false);
		}
		ImageView imgView = (ImageView) findViewById(R.id.user_data_image);
		if (null != user.getProfile_image_url()) {
			Drawable image = StatusDroidUtils.recoverImage(user
					.getProfile_image_url());

			imgView.setImageDrawable(image);
		}
	}

	@Override
	public void loadServiceAction() {
		int userId = getIntent().getIntExtra("userId", 0);
		User user;
		if (userId == 0) {
			user = statusNetAPI.getService().getUser();
		} else {
			try {
				user = statusNetAPI.getUserInfoById(String.valueOf(userId));
			} catch (StatusDroidException e) {
				showErrorAlert(e.getMessage());
				return;
			}
		}
		if (null != user) {
			fillViewFromUser(user);
		}
	}
}
