package edu.uoc.pfc.statusdroid.utils;

import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;

import android.database.Cursor;
import android.graphics.drawable.Drawable;
import android.util.Log;
import edu.uoc.pfc.statusdroid.content.StatusDroidDB;
import edu.uoc.pfc.statusdroid.exception.StatusDroidException;
import edu.uoc.pfc.statusdroid.helper.CryptoHelper;
import edu.uoc.pfc.statusdroid.model.ServerConfigData;

/**
 * Classe genèrica que conté aquelles utilitats generals que s'utilitzen per al
 * desenvolupament de la resta de funcionalitats.
 * 
 * @author daniel
 * 
 */
public class StatusDroidUtils {

	/**
	 * Mètode d'utilitat que recupera les dades de configuració d'un servidor
	 * StatusNet a partir del contingut d'un cursor.
	 * 
	 * @param cursor
	 *            Cursor on es troben les dades
	 * @return Dades de configuració recuperades
	 */
	public static ServerConfigData recoverServerConfigData(Cursor cursor,
			String seed) throws Exception {
		ServerConfigData config = new ServerConfigData();

		// Id
		config.setId(cursor.getInt(cursor
				.getColumnIndex(StatusDroidDB.ServerConfig._ID)));

		// Nom
		config.setName(cursor.getString(cursor
				.getColumnIndex(StatusDroidDB.ServerConfig.COLUMN_SERVER_NAME)));

		// URL
		config.setUrl(cursor.getString(cursor
				.getColumnIndex(StatusDroidDB.ServerConfig.COLUMN_SERVER_URI)));

		// Autoconnectar
		config.setAutconn(new Boolean(
				cursor.getString(cursor
						.getColumnIndex(StatusDroidDB.ServerConfig.COLUMN_SERVER_AUTOCONN))));

		// Usuari
		config.setUser(cursor.getString(cursor
				.getColumnIndex(StatusDroidDB.ServerConfig.COLUMN_SERVER_USER)));

		// Password
		String passwordEnc = cursor
				.getString(cursor
						.getColumnIndex(StatusDroidDB.ServerConfig.COLUMN_SERVER_PASSWORD));
		config.setPassword(CryptoHelper.decrypt(seed, passwordEnc));

		return config;
	}

	/**
	 * Mètode encarregat de descarregar una imatge d'un servidor i retornar el
	 * seu contingut
	 * 
	 * @param url
	 *            URL on es troba la imatge
	 * @return Imatge retornada
	 */
	public static Drawable recoverImage(String url) {
		try {
			InputStream is = (InputStream) fetch(url);
			Drawable d = Drawable.createFromStream(is, "src");
			return d;
		} catch (MalformedURLException e) {
			e.printStackTrace();
			return null;
		} catch (IOException e) {
			e.printStackTrace();
			return null;
		}
	}

	/**
	 * Mètode per recuperar les dades d'una URL
	 * 
	 * @param address
	 *            Direcció a recuperar
	 * @return Objecte recuperat
	 * @throws MalformedURLException
	 * @throws IOException
	 */
	private static Object fetch(String address) throws MalformedURLException,
			IOException {
		URL url = new URL(address);
		Object content = url.getContent();
		return content;
	}

	/**
	 * Mètode que centralitza la generació d'errors controlats
	 * 
	 * @param error
	 *            Missatge de l'error
	 * @param exception
	 *            Excepció que prova l'error
	 * @throws StatusDroidException
	 */
	public static void generateError(String place, String error,
			Exception exception) throws StatusDroidException {
		Log.e(place, error, exception);
		throw new StatusDroidException(error, exception);
	}
}
